@@ -22,6 +22,7 @@ test_that("test that data file is created correctly", {
     expect_equal(length(names(data_dictionary_newsmap_es)), 5)
     expect_equal(length(names(data_dictionary_newsmap_ja)), 5)
     expect_equal(length(names(data_dictionary_newsmap_ru)), 5)
+    expect_equal(length(names(data_dictionary_newsmap_it)), 5)
     expect_equal(length(names(data_dictionary_newsmap_zh_cn)), 5)
     expect_equal(length(names(data_dictionary_newsmap_zh_tw)), 5)
 })
@@ -34,6 +35,7 @@ test_that("test that dictionaries have the same countries", {
     es <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_es, 3))
     ja <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_ja, 3))
     ru <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_ru, 3))
+    it <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_it, 3))
     zh_cn <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_zh_cn, 3))
     zh_tw <- names(quanteda:::flatten_dictionary(data_dictionary_newsmap_zh_tw, 3))
 
@@ -42,6 +44,7 @@ test_that("test that dictionaries have the same countries", {
     expect_true(identical(en, es))
     expect_true(identical(en, ja))
     expect_true(identical(en, ru))
+    expect_true(identical(en, it))
     expect_true(identical(en, zh_cn))
     expect_true(identical(en, zh_tw))
 })
